@@ -4,7 +4,7 @@ use Mojo::JSON;
 use Mojo::Loader;
 use Mojo::Util 'decamelize';
 use Swagger2;
-use Swagger2::SchemaValidator;
+use JSON::Validator::OpenAPI;
 use constant DEBUG      => $ENV{SWAGGER2_DEBUG};
 use constant IO_LOGGING => $ENV{SWAGGER2_IO_LOGGING};    # EXPERIMENTAL
 
@@ -12,7 +12,7 @@ my $SKIP_OP_RE = qr(By|From|For|In|Of|To|With);
 my $LAYOUT = Mojo::Loader::data_section(__PACKAGE__, 'layouts/mojolicious_plugin_swagger.html.ep');
 
 has url => '';
-has _validator => sub { Swagger2::SchemaValidator->new; };
+has _validator => sub { JSON::Validator::OpenAPI->new; };
 
 sub dispatch_to_swagger {
   return undef unless $_[1]->{op} and $_[1]->{id} and ref $_[1]->{params} eq 'HASH';
@@ -90,7 +90,7 @@ sub register {
 
   local $config->{coerce} = $config->{coerce} || $ENV{SWAGGER_COERCE_VALUES};
   $self->_validator->coerce($config->{coerce}) if $config->{coerce};
-  $self->_validator->_api_spec($swagger->api_spec);
+  $self->_validator->schema($swagger->api_spec->data);
   $self->url($swagger->url);
   $app->helper(dispatch_to_swagger => \&dispatch_to_swagger)
     unless $app->renderer->get_helper('dispatch_to_swagger');
